==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/eo/heo92.h <==
/****************************************************************************

  module      : heo92.h

  -------------------------------------------------------------------------

  responsible : FrankH

  special area: x_cons
  description : common routines and definitions


  last changed: 2000-03-13  13:19
  see also    : example.html ...

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1998



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/


#ifndef HEO92_H
#define HEO92_H



/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "geo00_2.h"
#include "geo002.h"
#include "geo50_0.h"

#define SHOW_ALL_EO92        1
#define SHOW_ACTIVE_EO92     2
#define SHOW_RUNNABLE_EO92   3

#define SHOW_TT_ALL_EO92     2


#define IS_TASK_ACTIVE(_TaskType, _TaskState, _OMSCallback, _TypeToShow)                    \
        (                                                                                   \
            ( _TypeToShow == SHOW_TT_ALL_EO92 || _TaskType == _TypeToShow                   \
            /* || ( _TypeToShow == TT_US_EO00 &&                                            \
                    _TaskType   != TT_SV_EO00 && _TaskType != TT_DW_EO00 ) */               \
            ) &&                                                                            \
            (                                                                               \
                (1 == _OMSCallback) ||   /* PTS 1116931 */                                  \
                ( _TaskState != TSK_INACTIVE_EO00 && _TaskState != TSK_CONNECTWAIT_EO00 &&  \
                  _TaskType != TT_TI_EO00 &&                                                \
                  ( _TaskType == TT_US_EO00 || _TaskState != TSK_VSUSPEND_EO00 ) &&         \
                  ( _TaskState != TSK_VRECEIVE_EO00 )                                       \
                )                                                                           \
            )                                                                               \
        )


#define IS_TASK_RUNNABLE(_TaskType, _TaskState, _InQueue, _TypeToShow) \
      ( _TaskState  == TSK_RUNNING_EO00 || _InQueue == TASK_IS_IN_RUN_QUEUE_EO00 ) && \
      ( _TypeToShow == SHOW_TT_ALL_EO92 || _TypeToShow == _TaskType )


#define IS_TASK_TO_SHOW_EO92(_TaskType, _TaskState, _OMSCallback, _InQueue, _TypeToShow, _StateToShow) \
       ( ( (_StateToShow == SHOW_ALL_EO92 ) &&                                        \
           (_TypeToShow  == SHOW_TT_ALL_EO92     || _TypeToShow == _TaskType ) &&     \
           ( ( _TaskState != TSK_INITIALIZED_EO00 \
		    && _TaskState != TSK_INACTIVE_EO00 \
		    && _TaskState != TSK_CONNECTWAIT_EO00 ) || _TaskType == TT_UT_EO00 ) \
         ) ||                                                                       \
         ( _StateToShow == SHOW_ACTIVE_EO92 &&                                      \
           IS_TASK_ACTIVE ( _TaskType, _TaskState, _OMSCallback, _TypeToShow )      \
         ) ||                                                                       \
         ( _StateToShow == SHOW_RUNNABLE_EO92 &&                                    \
           IS_TASK_RUNNABLE(_TaskType, _TaskState, _InQueue, _TypeToShow )          \
         )                                                                          \
       )

/*===========================================================================*
 *  FUNCTION PROTOTYPES                                                      *
 *===========================================================================*/

/*************************/
#ifndef RUN_AS_SYSMON
/*************************/


externC void          e92_print_param          ( RTE_XPARAM_REC *xparam_rec,
                                                 char           *pszParam   );

externC int e92_set_new_param ( RTE_XPARAM_REC *XParam, 
                                char           *param_id, 
                                char           *param_val );

externC tsp00_Int4 
        eo92CreateTaskcluster (  TASK_CTRL           pFirstUKTTaskCtrl,
                                 char               *szCluster,
                                 tsp00_Int4          MaxClusterLen ) ;

/*************************/
#endif  /* RUN_AS_SYSMON */
/*************************/

externC bool          e92_strcont              ( char       *pszString1,
                                                 char       *pszString2,
                                                 int         MinLgt );

externC int           e92_get_tt_to_show       ( char           *param,
                                                 int            *tt_to_show ) ;

externC void          eo92_SecToDDHHMMSS       ( long  Sec, 
                                                 char *Buf ); /* ddd:hh:mm:ss: */

externC char         *eo92GetTaskStateName     ( teo00_Longint lState,
                                                 teo00_Longint lStateReason );

externC char         *eo92GetTaskTypeName      ( teo00_Uint1 TaskType ) ;
externC void          eo92_compress_path       ( char           *pszCompPathName,
                                                 char           *pszPathName,
                                                 teo00_Longuint  ulCompPathLen );

/* PTS 1114219 */
externC char *eo92GetConnectStateName(int connState, char *buffer, int len);
externC char *eo92GetConnectServiceName(int connState, char *buffer, int len);
externC char *eo92GetConnectProtocolName(int connProtocol, char *buffer, int len);
externC char *eo92GetSwapTypeName(int swapType, char *buffer, int len);

#endif  /* HEO92_H */

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/eo/heo92.h <==
/****************************************************************************

  module      : heo92.h

  -------------------------------------------------------------------------

  responsible : FrankH

  special area: x_cons
  description : common routines and definitions


  last changed: 2000-03-13  13:19
  see also    : example.html ...

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1998



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/


#ifndef HEO92_H
#define HEO92_H



/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "geo00_2.h"
#include "geo002.h"
#include "geo50_0.h"

#define SHOW_ALL_EO92        1
#define SHOW_ACTIVE_EO92     2
#define SHOW_RUNNABLE_EO92   3

#define SHOW_TT_ALL_EO92     2


#define IS_TASK_ACTIVE(_TaskType, _TaskState, _OMSCallback, _TypeToShow)                    \
        (                                                                                   \
            ( _TypeToShow == SHOW_TT_ALL_EO92 || _TaskType == _TypeToShow                   \
            /* || ( _TypeToShow == TT_US_EO00 &&                                            \
                    _TaskType   != TT_SV_EO00 && _TaskType != TT_DW_EO00 ) */               \
            ) &&                                                                            \
            (                                                                               \
                (1 == _OMSCallback) ||   /* PTS 1116933 */                                  \
                ( _TaskState != TSK_INACTIVE_EO00 && _TaskState != TSK_CONNECTWAIT_EO00 &&  \
                  _TaskType != TT_TI_EO00 &&                                                \
                  ( _TaskType == TT_US_EO00 || _TaskState != TSK_VSUSPEND_EO00 ) &&         \
                  ( _TaskState != TSK_VRECEIVE_EO00 )                                       \
                )                                                                           \
            )                                                                               \
        )


#define IS_TASK_RUNNABLE(_TaskType, _TaskState, _InQueue, _TypeToShow) \
      ( _TaskState  == TSK_RUNNING_EO00 || _InQueue == TASK_IS_IN_RUN_QUEUE_EO00 ) && \
      ( _TypeToShow == SHOW_TT_ALL_EO92 || _TypeToShow == _TaskType )


#define IS_TASK_TO_SHOW_EO92(_TaskType, _TaskState, _OMSCallback, _InQueue, _TypeToShow, _StateToShow) \
       ( ( (_StateToShow == SHOW_ALL_EO92 ) &&                                        \
           (_TypeToShow  == SHOW_TT_ALL_EO92     || _TypeToShow == _TaskType ) &&     \
           ( ( _TaskState != TSK_INITIALIZED_EO00 \
		    && _TaskState != TSK_INACTIVE_EO00 \
		    && _TaskState != TSK_CONNECTWAIT_EO00 ) || _TaskType == TT_UT_EO00 ) \
         ) ||                                                                       \
         ( _StateToShow == SHOW_ACTIVE_EO92 &&                                      \
           IS_TASK_ACTIVE ( _TaskType, _TaskState, _OMSCallback, _TypeToShow )      \
         ) ||                                                                       \
         ( _StateToShow == SHOW_RUNNABLE_EO92 &&                                    \
           IS_TASK_RUNNABLE(_TaskType, _TaskState, _InQueue, _TypeToShow )          \
         )                                                                          \
       )


#define AVG_TIME( State ) State.ulCount == 0 ? 0 : \
            ( (double)(tsp00_Int8)State.ulAbsMicroSeconds/1000000./ (double)State.ulCount )

#define AVG_ABS_TIME( State ) State.ulCount == 0 ? 0 : \
            ( (double)(tsp00_Int8)State.ulAbsMicroSeconds/1000000./ (double)State.ulCount )

#define AVG_REL_TIME( State ) State.ulCount == 0 ? 0 : \
            ( (double)(tsp00_Int8)State.ulRelMicroSeconds/1000000./ (double)State.ulCount )

#define PRI_PG_PER_IO(_StrFormat, _Stat, _StrPg, _StrPgPerIO )            \
      if ( _Stat.IOStat.ulCount )                                                \
        printf ( _StrFormat, _StrPg, _Stat.ulPageCount,                   \
                 _StrPgPerIO,                                             \
                 (float ) _Stat.ulPageCount / (float ) _Stat.IOStat.ulCount ) ;  \

#define PRI_STAT_TM( _StrFormat, _Stat, _StrCount, _StrRelTm, _StrAbsTm ) \
      if ( _Stat.ulCount && _Stat.ulAbsMicroSeconds)              \
        printf(_StrFormat, _StrCount, _Stat.ulCount,                      \
               _StrRelTm, AVG_REL_TIME( _Stat )  ,                        \
               _StrAbsTm, AVG_ABS_TIME( _Stat )  ) ;

/*===========================================================================*
 *  FUNCTION PROTOTYPES                                                      *
 *===========================================================================*/


externC void          e92_print_param          ( RTE_XPARAM_REC *xparam_rec,
                                                 char           *pszParam   );

externC int           e92_set_new_param ( RTE_XPARAM_REC *XParam, 
                                        char           *param_id, 
                                        char           *param_val );

externC tsp00_Int4 
        eo92CreateTaskcluster (  UKT_CTRL           pUKTCtrl,
                                 char               *szCluster,
                                 tsp00_Int4          MaxClusterLen ) ;

/* PTS 1106969 */
externC void eo92PrintTaskOMSStatistics( teo52_TaskOMSStatisticRec *pTaskOMSStat ) ;

externC void eo92PrintTaskCounts       ( tsp00_Int4                   TimeMeasurementActive,
                                         teo52_TaskStateStatisticRec *pTaskStateStat );
externC bool          e92_strcont              ( char       *pszString1,
                                                 char       *pszString2,
                                                 int         MinLgt );

externC int           e92_get_tt_to_show       ( char           *param,
                                                 int            *tt_to_show ) ;

externC void          eo92_SecToDDHHMMSS       ( long  Sec, 
                                                 char *Buf,
                                                 int   len ); /* ddd:hh:mm:ss: */

externC char         *eo92GetTaskStateName     ( tsp00_Int     lState,
                                                 tsp00_Int     lStateReason );

externC char         *eo92GetTaskTypeName      ( tsp00_Uint1   TaskType ) ;
externC void          eo92_compress_path       ( char          *pszCompPathName,
                                                 char          *pszPathName,
                                                 tsp00_Uint     ulCompPathLen );

externC char         *eo92GetOMSCallbackMethodName( int MethodIdx ) ; /* PTS 1106969 */

externC char *eo92GetConnectStateName(int connState, char *buffer, int len);
externC char *eo92GetConnectServiceName(int connState, char *buffer, int len);
externC char *eo92GetConnectProtocolName(int connProtocol, char *buffer, int len);
externC char *eo92GetSwapTypeName(int swapType, char *buffer, int len);

#endif  /* HEO92_H */
